@@ -210,7 +210,7 @@ export const newTracker = () => {
                         if (selectedFilter.event) {
                             // we now add control group information to event if the user is in the control group.
                             if (inControlGroup) {
-                                console.info('[WEM] Profile is in control group for target: ' + target + ', adding to personalization event...');
+                                console.debug('[WEM] Profile is in control group for target: ' + target + ', adding to personalization event...');
                                 selectedFilter.event.target.properties.inControlGroup = true;
                                 if (selectedFilter.event.target.properties.variants) {
                                     selectedFilter.event.target.properties.variants.forEach(variant => variant.inControlGroup = true);
@@ -219,7 +219,7 @@ export const newTracker = () => {
 
                             // send event to unomi
                             wem.collectEvent(wem._completeEvent(selectedFilter.event), function () {
-                                console.info('[WEM] Personalization event successfully collected.');
+                                console.debug('[WEM] Personalization event successfully collected.');
                             }, function () {
                                 console.error('[WEM] Could not send personalization event.');
                             });
@@ -405,7 +405,7 @@ export const newTracker = () => {
          */
         sendClickEvent: function (event, successCallback = undefined, errorCallback = undefined) {
             if (event.target.id || event.target.name) {
-                console.info('[WEM] Send click event');
+                console.debug('[WEM] Send click event');
                 var targetId = event.target.id ? event.target.id : event.target.name;
                 var clickEvent = wem.buildEvent('click',
                     wem.buildTarget(targetId, event.target.localName),
@@ -422,7 +422,7 @@ export const newTracker = () => {
                     var target = event.target;
 
                     wem.collectEvent(clickEvent, function (xhr) {
-                        console.info('[WEM] Click event successfully collected.');
+                        console.debug('[WEM] Click event successfully collected.');
                         if (successCallback) {
                             successCallback(xhr);
                         } else {
@@ -449,11 +449,11 @@ export const newTracker = () => {
          * @return {undefined}
          */
         sendVideoEvent: function (event, successCallback = undefined, errorCallback = undefined) {
-            console.info('[WEM] catching video event');
+            console.debug('[WEM] catching video event');
             var videoEvent = wem.buildEvent('video', wem.buildTarget(event.target.id, 'video', { action: event.type }), wem.buildSourcePage());
 
             wem.collectEvent(videoEvent, function (xhr) {
-                console.info('[WEM] Video event successfully collected.');
+                console.debug('[WEM] Video event successfully collected.');
                 if (successCallback) {
                     successCallback(xhr);
                 }
@@ -840,7 +840,7 @@ export const newTracker = () => {
          * @return {undefined}
          */
         _registerListenersForTrackedConditions: function () {
-            console.info('[WEM] Check for tracked conditions and attach related HTML listeners');
+            console.debug('[WEM] Check for tracked conditions and attach related HTML listeners');
 
             var videoNamesToWatch = [];
             var clickToWatch = [];
@@ -874,7 +874,7 @@ export const newTracker = () => {
                 // test attribute data-form-id to not add a listener on FF form
                 if (formName && wem.formNamesToWatch.indexOf(formName) > -1 && form.getAttribute('data-form-id') == null) {
                     // add submit listener on form that we need to watch only
-                    console.info('[WEM] Watching form ' + formName);
+                    console.debug('[WEM] Watching form ' + formName);
                     form.addEventListener('submit', wem._formSubmitEventListener, true);
                 }
             }
@@ -886,7 +886,7 @@ export const newTracker = () => {
                 if (video) {
                     video.addEventListener('play', wem.sendVideoEvent);
                     video.addEventListener('ended', wem.sendVideoEvent);
-                    console.info('[WEM] Watching video ' + videoName);
+                    console.debug('[WEM] Watching video ' + videoName);
                 } else {
                     console.warn('[WEM] Unable to watch video ' + videoName + ', video not found in the page');
                 }
@@ -899,7 +899,7 @@ export const newTracker = () => {
                     : document.getElementsByName(clickIdName)[0];
                 if (click) {
                     click.addEventListener('click', wem.sendClickEvent);
-                    console.info('[WEM] Watching click ' + clickIdName);
+                    console.debug('[WEM] Watching click ' + clickIdName);
                 } else {
                     console.warn('[WEM] Unable to watch click ' + clickIdName + ', element not found in the page');
                 }
@@ -1064,13 +1064,13 @@ export const newTracker = () => {
         _registerCallback: function (onLoadCallback, name = undefined, priority = 5) {
             if (wem.digitalData) {
                 if (wem.cxs) {
-                    console.info('[WEM] Trying to register context load callback, but context already loaded, executing now...');
+                    console.debug('[WEM] Trying to register context load callback, but context already loaded, executing now...');
                     if (onLoadCallback) {
-                        console.info('[WEM] executing context load callback: ' + (name ? name : 'Callback without name'));
+                        console.debug('[WEM] executing context load callback: ' + (name ? name : 'Callback without name'));
                         onLoadCallback(wem.digitalData);
                     }
                 } else {
-                    console.info('[WEM] registering context load callback: ' + (name ? name : 'Callback without name'));
+                    console.debug('[WEM] registering context load callback: ' + (name ? name : 'Callback without name'));
                     if (onLoadCallback) {
                         wem.digitalData.loadCallbacks = wem.digitalData.loadCallbacks || [];
                         wem.digitalData.loadCallbacks.push({
@@ -1081,7 +1081,7 @@ export const newTracker = () => {
                     }
                 }
             } else {
-                console.info('[WEM] Trying to register context load callback, but no digitalData conf found, creating it and registering the callback: ' + (name ? name : 'Callback without name'));
+                console.debug('[WEM] Trying to register context load callback, but no digitalData conf found, creating it and registering the callback: ' + (name ? name : 'Callback without name'));
                 wem.digitalData = {};
                 if (onLoadCallback) {
                     wem.digitalData.loadCallbacks = [];
@@ -1106,7 +1106,7 @@ export const newTracker = () => {
                 if (wem.cxs) {
                     console.error('[WEM] already loaded, too late...');
                 } else {
-                    console.info('[WEM] digitalData object present but not loaded, registering sort callback...');
+                    console.debug('[WEM] digitalData object present but not loaded, registering sort callback...');
                     wem.digitalData.personalizationCallback = wem.digitalData.personalizationCallback || [];
                     wem.digitalData.personalizationCallback.push({ personalization: personalization, callback: callback });
                 }
@@ -1149,7 +1149,7 @@ export const newTracker = () => {
             wem.cxs = JSON.parse(xhr.responseText);
 
             if (wem.digitalData.loadCallbacks && wem.digitalData.loadCallbacks.length > 0) {
-                console.info('[WEM] Found context server load callbacks, calling now...');
+                console.debug('[WEM] Found context server load callbacks, calling now...');
                 wem._executeLoadCallbacks(wem.digitalData);
 
                 if (wem.digitalData.personalizationCallback) {
@@ -1197,7 +1197,7 @@ export const newTracker = () => {
                 wem.digitalData.loadCallbacks
                     .sort((a, b) => a.priority - b.priority)
                     .forEach(loadCallback => {
-                        console.info('[WEM] executing context load callback: ' + (loadCallback.name ? loadCallback.name : 'callback without name'));
+                        console.debug('[WEM] executing context load callback: ' + (loadCallback.name ? loadCallback.name : 'callback without name'));
                         loadCallback.execute(callbackParam);
                     });
             }
@@ -1258,11 +1258,11 @@ export const newTracker = () => {
          * @return {undefined}
          */
         _formSubmitEventListener: function (event) {
-            console.info('[WEM] Registering form event callback');
+            console.debug('[WEM] Registering form event callback');
             var form = event.target;
             var formName = form.getAttribute('name') ? form.getAttribute('name') : form.getAttribute('id');
             if (formName && wem.formNamesToWatch.indexOf(formName) > -1) {
-                console.info('[WEM] catching form ' + formName);
+                console.debug('[WEM] catching form ' + formName);
 
                 var eventCopy = document.createEvent('Event');
                 // Define that the event name is 'build'.
